@@ -1,4 +1,7 @@
 <?php
+
+declare(strict_types=1);
+
 /**
  * phpMyAdmin ShapeFile library
  * <https://github.com/phpmyadmin/shapefile/>.
@@ -19,7 +22,8 @@
  * along with this program; if not, you can download one from
  * https://www.gnu.org/copyleft/gpl.html.
  */
-require_once '../vendor/autoload.php';
-require_once './read.php';
 
-display_file('../data/capitals.*');
+require_once __DIR__ . '/../vendor/autoload.php';
+require_once __DIR__ . '/read.php';
+
+display_file(__DIR__ . '/../data/capitals.*');
